@@ -48,7 +48,10 @@ def main_parser():
     """
     parser = argparse.ArgumentParser(add_help=False)
     parser.add_argument(
-        "-h", "--help", action=ArgparseHelper, help="show this help message and exit"
+        "-h",
+        "--help",
+        action=ArgparseHelper,
+        help="show this help message and exit",
     )
     cmd_parsers = parser.add_subparsers(
         dest=ComposeXSettings.command_arg, help="Command to execute."
