@@ -6,16 +6,8 @@
 Module to manage top level AWS CodeGuru profiles
 """
 
-from troposphere import (
-    AWS_NO_VALUE,
-    AWS_PARTITION,
-    AWS_REGION,
-    AWS_STACK_NAME,
-    GetAtt,
-    Join,
-    Ref,
-    Sub,
-)
+from compose_x_common.compose_x_common import keyisset
+from troposphere import GetAtt, Ref, Sub
 from troposphere.codeguruprofiler import ProfilingGroup
 
 from ecs_composex.codeguru_profiler.codeguru_profiler_params import (
@@ -25,7 +17,7 @@ from ecs_composex.codeguru_profiler.codeguru_profiler_params import (
     RES_KEY,
 )
 from ecs_composex.codeguru_profiler.codeguru_profiler_perms import ACCESS_TYPES
-from ecs_composex.common import build_template, keyisset
+from ecs_composex.common import build_template
 from ecs_composex.common.cfn_params import STACK_ID_SHORT
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.stacks import ComposeXStack
@@ -68,8 +60,10 @@ class CodeProfiler(XResource):
 
     policies_scaffolds = ACCESS_TYPES
 
-    def __init__(self, name, definition, module_name, settings):
-        super().__init__(name, definition, module_name, settings)
+    def __init__(self, name, definition, module_name, settings, mapping_key=None):
+        super().__init__(
+            name, definition, module_name, settings, mapping_key=mapping_key
+        )
         for count, env_name in enumerate(self.env_names):
             if env_name == self.name.replace("-", "_"):
                 self.env_names.pop(count)
