@@ -46,7 +46,6 @@ from troposphere.elasticloadbalancingv2 import (
 from ecs_composex.acm.acm_params import MOD_KEY as ACM_MOD_KEY
 from ecs_composex.acm.acm_params import RES_KEY as ACM_KEY
 from ecs_composex.cognito_userpool.cognito_params import MAPPINGS_KEY as COGNITO_MAP
-from ecs_composex.cognito_userpool.cognito_params import MOD_KEY as COGNITO_MOD
 from ecs_composex.cognito_userpool.cognito_params import RES_KEY as COGNITO_KEY
 from ecs_composex.cognito_userpool.cognito_params import (
     USERPOOL_ARN,
@@ -82,7 +81,8 @@ def handle_http2(value):
 
 def handle_drop_invalid_headers(value):
     return LoadBalancerAttributes(
-        Key="routing.http.drop_invalid_header_fields.enabled", Value=str(value).lower()
+        Key="routing.http.drop_invalid_header_fields.enabled",
+        Value=str(value).lower(),
     )
 
 
@@ -100,7 +100,8 @@ def handle_desync_mitigation_mode(value):
 def handle_timeout_seconds(timeout_seconds):
     if 1 < int(timeout_seconds) < 4000:
         return LoadBalancerAttributes(
-            Key="idle_timeout.timeout_seconds", Value=str(timeout_seconds).lower()
+            Key="idle_timeout.timeout_seconds",
+            Value=str(timeout_seconds).lower(),
         )
     else:
         raise ValueError(
@@ -473,6 +474,44 @@ def import_new_acm_certs(listener, src_name, settings, listener_stack):
     rectify_listener_protocol(listener)
 
 
+def handle_import_cognito_pool(the_pool, listener_stack, settings):
+    """
+    Function to map AWS Cognito Pool to attributes
+    :param the_pool:
+    :param listener_stack:
+    :param settings:
+    :return:
+    """
+    if the_pool.cfn_resource and not the_pool.lookup:
+        pool_id_param = Parameter(
+            f"{the_pool.logical_name}{USERPOOL_ID.title}", Type="String"
+        )
+        pool_arn = Parameter(
+            f"{the_pool.logical_name}{USERPOOL_ARN.title}", Type="String"
+        )
+        add_parameters(listener_stack.stack_template, [pool_id_param, pool_arn])
+        listener_stack.Parameters.update(
+            {
+                pool_id_param.title: Ref(the_pool.cfn_resource),
+                pool_arn.title: Ref(pool_arn),
+            }
+        )
+        return Ref(pool_id_param), Ref(pool_arn)
+    elif the_pool.lookup and not the_pool.cfn_resource:
+        if (
+            keyisset(COGNITO_MAP, settings.mappings)
+            and COGNITO_MAP not in listener_stack.stack_template.mappings
+        ):
+            listener_stack.stack_template.add_mapping(
+                COGNITO_MAP, settings.mappings[COGNITO_MAP]
+            )
+        return (
+            FindInMap(COGNITO_MAP, the_pool.logical_name, USERPOOL_ID.title),
+            FindInMap(COGNITO_MAP, the_pool.logical_name, USERPOOL_ARN.title),
+            FindInMap(COGNITO_MAP, the_pool.logical_name, USERPOOL_DOMAIN.title),
+        )
+
+
 def import_cognito_pool(src_name, settings, listener_stack):
     """
     Function to Import an Cognito Pool defined in x-cognito_pool
@@ -508,34 +547,7 @@ def import_cognito_pool(src_name, settings, listener_stack):
 
     if the_pool is None:
         raise LookupError("Failed to identify the cognito userpool to use", src_name)
-    if the_pool.cfn_resource and not the_pool.lookup:
-        pool_id_param = Parameter(
-            f"{the_pool.logical_name}{USERPOOL_ID.title}", Type="String"
-        )
-        pool_arn = Parameter(
-            f"{the_pool.logical_name}{USERPOOL_ARN.title}", Type="String"
-        )
-        add_parameters(listener_stack.stack_template, [pool_id_param, pool_arn])
-        listener_stack.Parameters.update(
-            {
-                pool_id_param.title: Ref(the_pool.cfn_resource),
-                pool_arn.title: Ref(pool_arn),
-            }
-        )
-        return Ref(pool_id_param), Ref(pool_arn)
-    elif the_pool.lookup and not the_pool.cfn_resource:
-        if (
-            keyisset(COGNITO_MAP, settings.mappings)
-            and COGNITO_MAP not in listener_stack.stack_template.mappings
-        ):
-            listener_stack.stack_template.add_mapping(
-                COGNITO_MAP, settings.mappings[COGNITO_MAP]
-            )
-        return (
-            FindInMap(COGNITO_MAP, the_pool.logical_name, USERPOOL_ID.title),
-            FindInMap(COGNITO_MAP, the_pool.logical_name, USERPOOL_ARN.title),
-            FindInMap(COGNITO_MAP, the_pool.logical_name, USERPOOL_DOMAIN.title),
-        )
+    handle_import_cognito_pool(the_pool, listener_stack, settings)
 
 
 def add_acm_certs_arn(listener, src_value, settings, listener_stack):
@@ -1131,7 +1143,8 @@ class Elbv2(XResource):
                 elif setting[3]:
                     mappings.append(
                         LoadBalancerAttributes(
-                            Key=setting[0], Value=str(self.parameters[setting[0]])
+                            Key=setting[0],
+                            Value=str(self.parameters[setting[0]]),
                         )
                     )
         return mappings
@@ -1148,7 +1161,8 @@ class Elbv2(XResource):
             for prop in self.properties["LoadBalancerAttributes"]:
                 attributes.append(
                     LoadBalancerAttributes(
-                        Key=prop, Value=self.properties["LoadBalancerAttributes"][prop]
+                        Key=prop,
+                        Value=self.properties["LoadBalancerAttributes"][prop],
                     )
                 )
         elif (
