@@ -3,7 +3,8 @@
 # Copyright 2020-2021 John Mille <john@compose-x.io>
 
 from os import path
-from ecs_composex.ecs_composex import X_KEY
+
+from ecs_composex.common.ecs_composex import X_KEY
 
 MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
 RES_KEY = f"{X_KEY}{MOD_KEY}"
